@@ -2,8 +2,8 @@ from elf_to_shellcode.resources import get_resource_path
 
 
 class ShellcodeLoader(object):
-    def __init__(self, loader_path, loader_size):
-        self.loader_symbols = get_resource_path(loader_path + ".symbols")
+    def __init__(self, symbols_path, loader_size):
+        self.loader_symbols = symbols_path
         self.symbols = {}
         self.base_address = 0
         with open(self.loader_symbols) as fp:
@@ -19,8 +19,11 @@ class ShellcodeLoader(object):
         self.base_address = self.symbols['loader_main']
 
     def get_relative_symbol_address(self, symbol_name):
-        sym_rel = self.symbols[symbol_name] - self.base_address
+        sym_rel = self.get_symbol_address(symbol_name) - self.base_address
         return sym_rel
 
     def has_symbol(self, symbol_name):
         return symbol_name in self.symbols
+
+    def get_symbol_address(self, symbol_name):
+        return self.symbols[symbol_name]
\ No newline at end of file
